@@ -141,7 +141,7 @@ gkbd_keyboard_config_merge_items (const gchar * parent,
 			return NULL;
 		strcat (buffer, parent);
 	}
-	if (child != NULL) {
+	if (child != NULL && *child != 0) {
 		if (strlen (child) >= XKL_MAX_CI_NAME_LENGTH)
 			return NULL;
 		strcat (buffer, "\t");
@@ -518,6 +518,7 @@ gkbd_keyboard_config_load_from_x_current (GkbdKeyboardConfig * kbd_config,
 					  XklConfigRec * data)
 {
 	gboolean own_data = data == NULL;
+	xkl_debug(150, "Copying config from X(current)\n");
 	if (own_data)
 		data = xkl_config_rec_new ();
 	if (xkl_config_rec_get_from_server (data, kbd_config->engine))
@@ -536,6 +537,7 @@ gkbd_keyboard_config_load_from_x_initial (GkbdKeyboardConfig * kbd_config,
 					  XklConfigRec * data)
 {
 	gboolean own_data = data == NULL;
+	xkl_debug(150, "Copying config from X(initial)\n");
 	if (own_data)
 		data = xkl_config_rec_new ();
 	if (xkl_config_rec_get_from_backup (data, kbd_config->engine))
